@@ -16,8 +16,7 @@ use function get_class;
  */
 final class MongoDBReferenceListener implements EventSubscriber
 {
-    /** @var ReferenceRepository */
-    private $referenceRepository;
+    private ReferenceRepository $referenceRepository;
 
     public function __construct(ReferenceRepository $referenceRepository)
     {
@@ -25,19 +24,17 @@ final class MongoDBReferenceListener implements EventSubscriber
     }
 
     /**
-     * {@inheritdoc}
+     * {@inheritDoc}
      */
-    public function getSubscribedEvents()
+    public function getSubscribedEvents(): array
     {
         return ['postPersist'];
     }
 
     /**
      * Populates identities for stored references
-     *
-     * @return void
      */
-    public function postPersist(LifecycleEventArgs $args)
+    public function postPersist(LifecycleEventArgs $args): void
     {
         $object = $args->getDocument();
 
