@@ -7,23 +7,24 @@ namespace Doctrine\Tests\Common\DataFixtures\TestEntity;
 use Doctrine\ORM\Mapping as ORM;
 
 /** @ORM\Entity() */
+#[ORM\Entity]
 class Group
 {
     /**
      * @ORM\Column(type="integer")
      * @ORM\Id
-     *
-     * @var int|null
      */
-    private $id;
+    #[ORM\Column]
+    #[ORM\Id]
+    private ?int $id = null;
 
     /**
      * @ORM\Column(length=32)
      * @ORM\Id
-     *
-     * @var string|null
      */
-    private $code;
+    #[ORM\Column(length: 32)]
+    #[ORM\Id]
+    private ?string $code = null;
 
     public function setId(int $id): void
     {
