@@ -7,23 +7,22 @@ namespace Doctrine\Tests\Common\DataFixtures\TestEntity;
 use Doctrine\ORM\Mapping as ORM;
 
 /** @ORM\Entity */
+#[ORM\Entity]
 class Role
 {
     /**
      * @ORM\Column(type="integer")
      * @ORM\Id
      * @ORM\GeneratedValue(strategy="IDENTITY")
-     *
-     * @var int|null
      */
-    private $id;
+    #[ORM\Column]
+    #[ORM\Id]
+    #[ORM\GeneratedValue(strategy: 'IDENTITY')]
+    private ?int $id = null;
 
-    /**
-     * @ORM\Column(length=50)
-     *
-     * @var string|null
-     */
-    private $name;
+    /** @ORM\Column(length=50) */
+    #[ORM\Column(length: 50)]
+    private ?string $name = null;
 
     public function getId(): ?int
     {
