@@ -7,15 +7,16 @@ namespace Doctrine\Tests\Common\DataFixtures\TestPurgeEntity;
 use Doctrine\ORM\Mapping as ORM;
 
 /** @ORM\Entity */
+#[ORM\Entity]
 class ExcludedEntity
 {
     /**
      * @ORM\Column(type="integer")
      * @ORM\Id
-     *
-     * @var int
      */
-    private $id;
+    #[ORM\Column]
+    #[ORM\Id]
+    private ?int $id = null;
 
     public function setId(int $id): void
     {
