@@ -5,12 +5,10 @@ declare(strict_types=1);
 namespace Doctrine\Tests\Common\DataFixtures\TestValueObjects;
 
 use JsonSerializable;
-use Serializable;
 
-class Uuid implements JsonSerializable, Serializable
+class Uuid implements JsonSerializable
 {
-    /** @var string $id */
-    private $id;
+    private string $id;
 
     public function __construct(string $id)
     {
@@ -27,17 +25,6 @@ class Uuid implements JsonSerializable, Serializable
         return $this->id;
     }
 
-    public function serialize(): string
-    {
-        return $this->id;
-    }
-
-    /** @param string $serialized */
-    public function unserialize($serialized): void
-    {
-        $this->id = $serialized;
-    }
-
     public function __serialize(): array
     {
         return ['id' => $this->id];
